@@ -28,7 +28,7 @@
 #' Will return NULL if offline and not available
 #' @param year character vector of length one, e.g. "2011"
 #' @param offline single logical value
-#' @keywords internal
+#' @keywords internal datagen
 rtf_fetch_year <- function(year, offline = TRUE) {
   year <- as.character(year)
   assert_string(year, pattern = "[[:digit:]]{4}")
@@ -53,32 +53,26 @@ rtf_fetch_year <- function(year, offline = TRUE) {
 #'   implemented thus far
 #' @template save_data
 #' @template verbose
-#' @source
-#' http://ftp.cdc.gov/pub/Health_Statistics/NCHS/Publications/ICD9-CM/2011/Dtab12.zip
-#' and similar files run from 1996 to 2011.
-#' @keywords internal
-rtf_parse_year <- function(year = "2011", ..., save_data = FALSE, verbose = FALSE, offline = TRUE) {
+#' @source \url{https://www.cdc.gov/nchs/icd/icd9cm.htm} Navigate to
+#' 'Dtab12.zip' in the 2011 data. and similar files run from 1996 to 2011.
+#' @keywords internal datagen
+rtf_parse_year <- function(year = "2011", ..., save_data = FALSE,
+                           verbose = FALSE, offline = TRUE) {
   assert_string(year)
   assert_flag(save_data)
   assert_flag(verbose)
   assert_flag(offline)
-
   f_info_rtf <- rtf_fetch_year(year, offline = offline)
-
   if (is.null(f_info_rtf))
     stop("RTF data for year ", year, " unavailable.")
-
   fp <- f_info_rtf$file_path
-
   fp_conn <- file(fp, encoding = "ASCII")
   on.exit(close(fp_conn))
   rtf_lines <- readLines(fp_conn, warn = FALSE, encoding = "ASCII")
-
   out <- rtf_parse_lines(rtf_lines, verbose = verbose,
                          ..., save_extras = save_data)
   out <- swap_names_vals(out)
   out <- sort_icd.icd9(out, short_code = FALSE)
-
   invisible(
     data.frame(
       code = out %>%
@@ -98,7 +92,6 @@ rtf_pre_filter <- function(filtered, ...) {
   # all non-par lines
   for (i in rev(non_par_lines))
     filtered[i - 1] <- paste(filtered[i - 1], filtered[i], sep = "")
-
   filtered <- grep("^\\\\par", filtered, value = TRUE, ...)
   filtered <- rtf_fix_unicode(filtered, ...)
   # extremely long terminal line in primary source is junk
@@ -119,33 +112,28 @@ rtf_pre_filter <- function(filtered, ...) {
 #'   contents being the descriptions from the RTF source. Elsewhere I do this
 #'   the other way around, but the tests are now wired for this layout. 'Tidy'
 #'   data would favour having an unnamed two-column data frame.
-#' @keywords internal
-rtf_parse_lines <- function(rtf_lines, verbose = FALSE, save_extras = FALSE, ...) {
+#' @keywords internal datagen
+rtf_parse_lines <- function(rtf_lines, verbose = FALSE,
+                            save_extras = FALSE, ...) {
   assert_character(rtf_lines)
   assert_flag(verbose)
   assert_flag(save_extras)
-
   filtered <- rtf_pre_filter(rtf_lines, ...)
-
   rtf_make_majors(filtered, save = save_extras, ...)
   rtf_make_sub_chapters(filtered, ..., save = save_extras)
-
   # this is so ghastly: find rows with sequare brackets containing definition of
   # subset of fourth or fifth digit codes. Need to pull code from previous row,
   # and create lookup, so we can exclude these when processing the fourth an
   # fifth digits
   invalid_qual <- rtf_make_invalid_qual(filtered, ...)
-
   # several occurances of "Requires fifth digit", referring back to the previous
   # higher-level definition, without having the parent code in the line itself
   re_fifth_range_other <- "fifth +digit +to +identify +stage"
-
   fifth_backref <- grep(re_fifth_range_other, filtered, ...)
   # for these, construct a string which will be captured in the next block
   # e.g. "Requires fifth digit to identify stage:" becomes
   # "Requires fifth digit to identify stage: 634 Spontaneous abortion"
   filtered[fifth_backref] <- paste(filtered[fifth_backref], filtered[fifth_backref - 1])
-
   re_fourth_range <- "fourth-digit.+categor"
   fourth_rows <- grep(re_fourth_range, filtered, ...)
   lookup_fourth <- rtf_generate_fourth_lookup(filtered, fourth_rows)
@@ -155,7 +143,6 @@ rtf_parse_lines <- function(rtf_lines, verbose = FALSE, save_extras = FALSE, ...
   filtered[fourth_digit_zero_lines] %>%
     str_pair_match("(.*category )([[:digit:]]{3})$", ...) %>%
     unname -> fourth_digit_zero_categories
-
   # deal with 657 and 672 (in the default RTF), by appending the elements to the
   # end of the input list. argh.
   for (categ in fourth_digit_zero_categories) {
@@ -163,16 +150,13 @@ rtf_parse_lines <- function(rtf_lines, verbose = FALSE, save_extras = FALSE, ...
     filtered[length(filtered) + 1] <-
       paste0(categ, ".0 ", str_pair_match(parent_row, "([[:digit:]]{3} )(.+)", ...))
   }
-
   lookup_fifth <- rtf_make_lookup_fifth(filtered, re_fifth_range_other)
-
   filtered <- rtf_filter_excludes(filtered, ...)
   out <- rtf_main_filter(filtered, ...)
   out <- c(out, rtf_lookup_fourth(out = out, lookup_fourth = lookup_fourth))
   out <- c(out, rtf_lookup_fifth(out, lookup_fifth))
   out <- rtf_fix_duplicates(out, verbose)
   out <- out[-which(names(out) %in% invalid_qual)]
-
   rtf_fix_quirks_2015(out)
 }
 
@@ -180,7 +164,7 @@ rtf_parse_lines <- function(rtf_lines, verbose = FALSE, save_extras = FALSE, ...
 #'
 #' Ignore excluded codes, and fix some odd-balls so they don't get dropped
 #' "707.02Upper back", "066.40West Nile fever, unspecified", etc
-#' @keywords internal
+#' @keywords internal datagen
 rtf_filter_excludes <- function(filtered, ...) {
   # drop excludes: lines with bracketed codes (removes chapter headings)
   re_bracketed <- paste0("\\((", re_icd9_decimal_bare,
@@ -188,7 +172,6 @@ rtf_filter_excludes <- function(filtered, ...) {
   filtered <- grep(re_bracketed, filtered, value = TRUE, invert = TRUE, ...)
   filtered <- grep("Exclude", filtered,
                    value = TRUE, invert = TRUE, ...)
-
   sub("((70[[:digit:]]\\.[[:digit:]]{2})|066\\.40)([[:alpha:]])", "\\1 \\2",
       filtered, ...)
 }
@@ -198,11 +181,10 @@ rtf_filter_excludes <- function(filtered, ...) {
 #' Keep some more information, but we'll just take the primary description for
 #' each item, i.e. where a code begins a line. Some codes have ten or so
 #' alternative descriptions, e.g. 410.0
-#' @keywords internal
+#' @keywords internal datagen
 rtf_main_filter <- function(filtered, ...) {
   filtered <- grep(paste0("^[[:space:]]*(", re_icd9_decimal_strict_bare, ") "),
                    filtered, value = TRUE, ...)
-
   # spaces to single
   filtered <- gsub("[[:space:]]+", " ", filtered, ...)
   # fix a few things, e.g. "040. 1 Rhinoscleroma", "527 .0 Atrophy"
@@ -230,19 +212,14 @@ rtf_make_majors <- function(filtered, ..., save = FALSE) {
                       x = major_lines, perl = TRUE, useBytes = use_bytes)
   names(icd9_majors) <- gsub(pattern = re_major_split, replacement = "\\2",
                              x = major_lines, perl = TRUE, useBytes = use_bytes)
-
   # this sub-chapter is simply missing from the otherwise consistent RTF way
   # 'major' types are reported:
   icd9_majors[["Place of occurrence"]] <- "E849"
-
   # There are some duplicates created by the major search, mostly E001 to E030
   # which are just listed twice in RTF. Also 199 (with punctuation difference),
   # 209 and 239.
   icd9_majors <- icd9_majors[!duplicated(icd9_majors)]
-
-  if (save)
-    save_in_data_dir(icd9_majors)
-
+  if (save) save_in_data_dir(icd9_majors)
   invisible(icd9_majors)
 }
 
@@ -256,13 +233,17 @@ rtf_make_sub_chapters <- function(filtered, ..., save = FALSE) {
     grep(re_subchap_either, filtered,
          value = TRUE, ...)
   )
-  # The entire "E" block is incorrectly identified here, so make sure it is gone:
-  icd9_sub_chapters["Supplementary Classification Of Factors Influencing Health Status And Contact With Health Services"] <- NULL
-  icd9_sub_chapters["Supplementary Classification Of External Causes Of Injury And Poisoning"] <- NULL
-
-  if (save)
-    save_in_data_dir(icd9_sub_chapters)
-
+  # The entire "E" block is incorrectly identified here, so make sure it is gone
+  pref <- "Supplementary Classification Of"
+  s <- paste(
+    pref,
+    "Factors Influencing Health Status And Contact With Health Services")
+  t <- paste(
+    pref,
+    "Supplementary Classification Of External Causes Of Injury And Poisoning")
+  icd9_sub_chapters[s] <- NULL
+  icd9_sub_chapters[t] <- NULL
+  if (save) save_in_data_dir(icd9_sub_chapters)
   invisible(icd9_sub_chapters)
 }
 
@@ -293,7 +274,7 @@ rtf_make_invalid_qual <- function(filtered, ...) {
 #' codes they augment
 #' @return named character vector, names are the ICD codes, values are the
 #'   descriptions
-#' @keywords internal
+#' @keywords internal datagen
 rtf_generate_fourth_lookup <- function(filtered, fourth_rows, verbose = FALSE) {
   lookup_fourth <- c()
   for (f in fourth_rows) {
@@ -303,7 +284,6 @@ rtf_generate_fourth_lookup <- function(filtered, fourth_rows, verbose = FALSE) {
       string = filtered[seq(f + 1, f + 37)],
       pattern = "^([[:digit:]])[[:space:]](.*)"
     )
-
     re_fourth_defined <- paste(c("\\.[", names(fourth_suffices), "]$"), collapse = "")
     # drop members of range which don't have defined fourth digit
     range <- grep(re_fourth_defined, range, value = TRUE)
@@ -330,7 +310,7 @@ rtf_generate_fourth_lookup <- function(filtered, fourth_rows, verbose = FALSE) {
 #'
 #' use the lookup table of fourth digit
 #'
-#' @keywords internal
+#' @keywords internal datagen
 rtf_lookup_fourth <- function(out, lookup_fourth, verbose = FALSE) {
   rtf_lookup_fourth_alt_env(out = out, lookup_fourth = lookup_fourth, verbose = verbose)
 }
@@ -379,7 +359,6 @@ rtf_make_lookup_fifth <- function(filtered, re_fifth_range_other, ..., verbose =
   re_fifth_range <- "ifth-digit subclas|fifth-digits are for use with codes"
   re_fifth_rows <- paste(re_fifth_range, re_fifth_range_other, sep = "|")
   fifth_rows <- grep(pattern = re_fifth_rows, x = filtered, ...)
-
   # lookup_fifth will contain vector of suffices, with names being the codes
   # they augment
   lookup_fifth <- c()
@@ -389,7 +368,6 @@ rtf_make_lookup_fifth <- function(filtered, re_fifth_range_other, ..., verbose =
     fifth_suffices <- filtered[seq(f + 1, f + 20)] %>%
       grep(pattern = "^[[:digit:]][[:space:]].*", value = TRUE, ...) %>%
       str_pair_match("([[:digit:]])[[:space:]](.*)", ...)
-
     re_fifth_defined <- paste(c("\\.[[:digit:]][", names(fifth_suffices), "]$"), collapse = "")
     # drop members of range which don't have defined fifth digit
     range <- grep(re_fifth_defined, range, value = TRUE, ...)
@@ -404,12 +382,10 @@ rtf_make_lookup_fifth <- function(filtered, re_fifth_range_other, ..., verbose =
     }
     lookup_fifth <- c(lookup_fifth, range)
   }
-
   # V30-39 are a special case because combination of both fourth and fifth
   # digits are specified
   re_fifth_range_V30V39 <- "The following two fifths-digits are for use with the fourth-digit \\.0"
   re_V30V39_fifth <- "V3[[:digit:]]\\.0[01]$"
-
   lines_V30V39 <- grep(re_fifth_range_V30V39, filtered)
   stopifnot(length(lines_V30V39) == 1)
   filtered[seq(from = lines_V30V39 + 1, to = lines_V30V39 + 3)] %>%
@@ -437,7 +413,6 @@ rtf_lookup_fifth_alt_base <- function(out, lookup_fifth, verbose = FALSE) {
     lf <- lookup_fifth[f_num]
     f <- names(lf)
     parent_code <- substr(f, 0, nchar(f) - 1)
-
     if (parent_code %in% names(out)) {
       pair_fifth <- paste(out[parent_code], lf, sep = ", ")
       names(pair_fifth) <- f
@@ -455,7 +430,6 @@ rtf_lookup_fifth_alt_env <- function(out, lookup_fifth, verbose = FALSE) {
   out_fifth <- character(5000) # 2011 data is 4870 long
   n <- 1L
   out_env <- list2env(as.list(out))
-
   for (f_num in seq_along(lookup_fifth)) {
     lf <- lookup_fifth[f_num]
     f <- names(lf)
@@ -480,7 +454,7 @@ rtf_lookup_fifth_alt_env <- function(out, lookup_fifth, verbose = FALSE) {
 #' split over lines... This needs care in Windows, or course. Maybe Mac, too?
 #'
 #' First: c cedilla, e grave, e acute Then:  n tilde, o umlaut
-#' @keywords internal manip
+#' @keywords internal datagen
 rtf_fix_unicode <- function(filtered, ...) {
   filtered <- gsub("\\\\'e7", "\u00e7", filtered, ...) # c cedilla
   filtered <- gsub("\\\\'e8", "\u00e8", filtered, ...) # e gravel
@@ -494,12 +468,10 @@ rtf_fix_unicode <- function(filtered, ...) {
 #'
 #' clean up duplicates (about 350 in 2015 data), mostly one very brief
 #' description and a correct longer one; or, identical descriptions
-#' @keywords internal
+#' @keywords internal datagen
 rtf_fix_duplicates <- function(out, verbose) {
-
   dupes <- out[duplicated(names(out)) | duplicated(names(out), fromLast = TRUE)]
   dupes <- unique(names(dupes))
-
   for (d in dupes) {
     dupe_rows <- which(names(out) == d)
     if (all(out[dupe_rows[1]] == out[dupe_rows[-1]])) {
@@ -521,7 +493,7 @@ rtf_fix_duplicates <- function(out, verbose) {
 #' most specific) some may well apply to other years 650-659 ( and probably many
 #' others don't use whole subset of fourth or fifth digit qualifiers) going to
 #' have to parse these, e.g. [0,1,3], as there are so many...
-#' @keywords internal manip
+#' @keywords internal datagen
 rtf_fix_quirks_2015 <- function(out) {
   out <- out[grep("65[12356789]\\.[[:digit:]][24]", names(out), invert = TRUE)]
 
@@ -546,21 +518,18 @@ rtf_fix_quirks_2015 <- function(out) {
 #'   definition. This needs to be whittled down to just those matching fifth
 #'   digits, but we haven't parsed them yet.
 #' @template verbose
-#' @keywords internal
+#' @keywords internal datagen
 rtf_parse_fifth_digit_range <- function(row_str, verbose = FALSE) {
   assert_string(row_str)
   assert_flag(verbose)
-
   out <- c()
   # get numbers and number ranges
   row_str %>%
     strsplit("[, :;]") %>%
     unlist %>%
     grep(pattern = "[VvEe]?[0-9]", value = TRUE) -> vals
-
   if (verbose)
     message("vals are:", paste(vals, collapse = ", "))
-
   # sometimes  we get things like:
   # [1] "345.0" ".1"    ".4-.9"
   grepl(pattern = "^\\.[[:digit:]]+.*", vals) -> decimal_start
@@ -585,7 +554,6 @@ rtf_parse_fifth_digit_range <- function(row_str, verbose = FALSE) {
     }
     vals <- vals[1] # still need to process the base code
   }
-
   for (v in vals) {
     # take care of ranges
     if (grepl("-", v)) {
@@ -594,15 +562,13 @@ rtf_parse_fifth_digit_range <- function(row_str, verbose = FALSE) {
       stopifnot(all(is_valid.icd9(pair, short_code = FALSE)))
       if (verbose)
         message("expanding explicit range ", pair[1], " to ", pair[2])
-      # formatting errors can lead to huge range expansions, e.g. "8-679"
-
+      # formatting errors can lead to huge range expansions, e.g. "8-679".
       # quickly strip off V or E part for comparison
       pair_one <- gsub("[^[:digit:]]", "", pair[1])
       pair_two <- gsub("[^[:digit:]]", "", pair[2])
       if (as.integer(pair_two) - as.integer(pair_one) > 10) {
         warning("probable formatting misinterpretation: huge range expansion")
       }
-
       out <- c(out, pair[1] %i9da% pair[2])
     } else {
       # take care of single values
@@ -611,7 +577,6 @@ rtf_parse_fifth_digit_range <- function(row_str, verbose = FALSE) {
                    get_invalid.icd9(v, short_code = FALSE)))
       out <- c(out, children.icd9(v, short_code = FALSE, defined = FALSE))
     }
-
   }
   out
 }
@@ -644,16 +609,16 @@ rtf_parse_qualifier_subset <- function(qual) {
 #'
 #' just for \\tab, replace with space, otherwise, drop RTF tags entirely
 #' @param x vector of character strings containing RTF
-#' @keywords internal manip
+#' @keywords internal datagen
 rtf_strip <- function(x, ...) {
   #nolint start
   x <- gsub("\\\\tab ", " ", x, ...)
-  x <- gsub("\\\\[[:punct:]]", "", x, ...) # control symbols only, not control words
+  x <- gsub("\\\\[[:punct:]]", "", x, ...) # control symbols, not control words
   x <- gsub("\\\\lsdlocked[ [:alnum:]]*;", "", x, ...) # special case
   x <- gsub("\\{\\\\bkmk(start|end).*?\\}", "", x, ...)
   # no backslash in this next list, others removed from
   # http://www.regular-expressions.info/posixbrackets.html
-  # punct is defined as:       [!"\#$%&'()*+,\-./:;<=>?@\[\\\]^_`{|}~], not quite the same
+  # punct not quite the same: [!"\#$%&'()*+,\-./:;<=>?@\[\\\]^_`{|}~]
   x <- gsub("\\\\[-[:alnum:]]*[ !\"#$%&'()*+,-./:;<=>?@^_`{|}~]?", "", x, ...)
   x <- gsub(" *(\\}|\\{)", "", x, ...)
   trim(x)
