@@ -18,13 +18,19 @@
 #ifndef RANGES_H_
 #define RANGES_H_
 
-#include <stddef.h>     // for size_t
 #include "icd_types.h"
-#include "range-const.h"                    // for v_empty_std, v0, v0_std, v1
+#include "range-const.h"
 
-CV icd9ChildrenShort(CV icd9Short, const VecStr& icd9cmReal, bool onlyReal = true);
-CV icd9ChildrenShortUnordered(CV icd9Short, const VecStr& icd9cmReal, bool onlyReal = true);
-CV icd9ChildrenDecimalCpp(CV icd9Decimal, const VecStr& icd9cmReal, bool onlyReal = true);
-CV icd9ExpandMinor(const Str& mnr, bool isE = false);
+CV icd9ChildrenShort(CV icd9Short,
+                     const VecStr& icd9cmReal,
+                     bool onlyReal = true);
+CV icd9ChildrenShortUnordered(CV icd9Short,
+                              const VecStr& icd9cmReal,
+                              bool onlyReal = true);
+CV icd9ChildrenDecimalCpp(CV icd9Decimal,
+                          const VecStr& icd9cmReal,
+                          bool onlyReal = true);
+CV icd9ExpandMinor(const Str& mnr,
+                   bool isE = false);
 
 #endif /* RANGES_H_ */
