@@ -121,10 +121,14 @@ test_that("condense big lists of comorbidities", {
   # this is a useful but slow (8s on my PC) test because the data weren't
   # generated by just expanding base ranges (which is how the condense works in
   # reverse)
-  expect_error(ahrq <- lapply(icd9_map_ahrq[c(1, 30)], icd_condense.icd9, short_code = TRUE, defined = FALSE), regexp = NA)
-  expect_error(qd <- lapply(icd9_map_quan_deyo[c(1, 17)], icd_condense.icd9, short_code = TRUE, defined = FALSE), regexp = NA)
-  expect_error(qe <- lapply(icd9_map_quan_elix[c(1, 30)], icd_condense.icd9, short_code = TRUE, defined = FALSE), regexp = NA)
-  expect_error(elix <- lapply(icd9_map_elix[c(1, 30)], icd_condense.icd9, short_code = TRUE, defined = FALSE), regexp = NA)
+  ahrq <- lapply(icd9_map_ahrq[c(1, 30)],
+                 icd_condense.icd9, short_code = TRUE, defined = FALSE)
+  qd <- lapply(icd9_map_quan_deyo[c(1, 17)],
+               icd_condense.icd9, short_code = TRUE, defined = FALSE)
+  qe <- lapply(icd9_map_quan_elix[c(1, 30)],
+               icd_condense.icd9, short_code = TRUE, defined = FALSE)
+  elix <- lapply(icd9_map_elix[c(1, 30)],
+                 icd_condense.icd9, short_code = TRUE, defined = FALSE)
   expect_is(ahrq, class = "list")
   expect_is(elix, class = "list")
   expect_is(qd, class = "list")
@@ -596,67 +600,14 @@ ac <-  lapply(icd9_map_ahrq, function(x) {
   f[!is.na(f)]
 })
 
-test_that("give factor instead of char to icd9ComorbidShortCpp", {
-  pts$visit_id <- factor(pts$visit_id)
-  expect_error(
-    icd9ComorbidShortCpp(pts, ac, visitId = "visit_id", icd9Field = "icd9Field"),
-    "character vector"
-  )
-})
-
-test_that("control params don't affect result of comorbid calc", {
-  pts$visit_id <- as_char_no_warn(pts$visit_id)
-  pts$code %<>% as.factor
-  upts <- length(unique(pts$visit_id))
-  expect_identical(
-    icd9ComorbidShortCpp(pts, ac, visitId = "visit_id", icd9Field = "icd9Field", threads = 1, chunk_size = 32),
-    icd9ComorbidShortCpp(pts, ac, visitId = "visit_id", icd9Field = "icd9Field", threads = 3, chunk_size = 32)
-  )
-  expect_identical(
-    icd9ComorbidShortCpp(pts, ac, visitId = "visit_id", icd9Field = "icd9Field", threads = 2, chunk_size = 32),
-    icd9ComorbidShortCpp(pts, ac, visitId = "visit_id", icd9Field = "icd9Field", threads = 5, chunk_size = 32)
-  )
-  expect_identical(
-    icd9ComorbidShortCpp(pts, ac, visitId = "visit_id", icd9Field = "icd9Field", threads = 3, chunk_size = 1),
-    icd9ComorbidShortCpp(pts, ac, visitId = "visit_id", icd9Field = "icd9Field", threads = 3, chunk_size = 32)
-  )
-  expect_identical(
-    icd9ComorbidShortCpp(pts, ac, visitId = "visit_id", icd9Field = "icd9Field", threads = 4, chunk_size = upts - 1),
-    icd9ComorbidShortCpp(pts, ac, visitId = "visit_id", icd9Field = "icd9Field", threads = 4, chunk_size = upts)
-  )
-  expect_identical(
-    icd9ComorbidShortCpp(pts, ac, visitId = "visit_id", icd9Field = "icd9Field", threads = 4, chunk_size = upts - 1),
-    icd9ComorbidShortCpp(pts, ac, visitId = "visit_id", icd9Field = "icd9Field", threads = 4, chunk_size = upts + 1)
-  )
-  expect_identical(
-    icd9ComorbidShortCpp(pts, ac, visitId = "visit_id", icd9Field = "icd9Field", threads = 4, chunk_size = upts + 1),
-    icd9ComorbidShortCpp(pts, ac, visitId = "visit_id", icd9Field = "icd9Field", threads = 4, chunk_size = upts)
-  )
-  expect_identical(
-    icd9ComorbidShortCpp(pts, ac, visitId = "visit_id", icd9Field = "icd9Field", threads = 3, chunk_size = upts - 2, omp_chunk_size = 1), # nolint
-    icd9ComorbidShortCpp(pts, ac, visitId = "visit_id", icd9Field = "icd9Field", threads = 3, chunk_size = upts + 2, omp_chunk_size = 1) # nolint
-  )
-  expect_identical(
-    icd9ComorbidShortCpp(pts, ac, visitId = "visit_id", icd9Field = "icd9Field", threads = 3, chunk_size = upts - 2, omp_chunk_size = 11), # nolint
-    icd9ComorbidShortCpp(pts, ac, visitId = "visit_id", icd9Field = "icd9Field", threads = 3, chunk_size = upts + 2, omp_chunk_size = 11) # nolint
-  )
-  expect_identical(
-    icd9ComorbidShortCpp(pts, ac, visitId = "visit_id", icd9Field = "icd9Field", threads = 3, chunk_size = upts, omp_chunk_size = 1), # nolint
-    icd9ComorbidShortCpp(pts, ac, visitId = "visit_id", icd9Field = "icd9Field", threads = 3, chunk_size = upts, omp_chunk_size = 11) # nolint
-  )
-  expect_identical(
-    icd9ComorbidShortCpp(pts, ac, visitId = "visit_id", icd9Field = "icd9Field"),
-    icd9ComorbidShortCpp(pts, ac, visitId = "visit_id", icd9Field = "icd9Field", threads = 3, chunk_size = 3, omp_chunk_size = 5) # nolint
-  )
-})
-
 test_that("failing example", {
   mydf <- data.frame(visit_id = c("a", "b", "c"),
                      icd9 = c("441", "412.93", "044.9"))
   cmb <- icd9_comorbid_quan_deyo(mydf, short_code = FALSE, hierarchy = TRUE)
   expect_false("names" %in% names(attributes(cmb)))
-  icd_charlson(mydf, isShort = FALSE)
-  expect_is(icd_charlson(mydf, isShort = FALSE, return_df = TRUE), "data.frame")
+  icd_charlson(mydf, short_code = FALSE)
+  expect_is(icd_charlson(mydf, short_code = FALSE, return_df = TRUE),
+            "data.frame")
   icd_charlson_from_comorbid(cmb)
 })
 
